# Supplementary Material for "Combining Voting and Abstract Argumentation to Understand Online Discussions"

This is the supplementary material belonging to the paper "Combining Voting and Abstract Argumentation to Understand Online Discussions" by Michael Bernreiter, Jan Maly, Oliviero Nardi and Stefan Woltran, published in the proceedings of the 23rd International Conference on Autonomous Agents and Multiagent Systems (AAMAS-2024).

The supplementary material consists of the code and data used to run the experiments featured in the paper,  with a full record of the results.

In the following, we will provide instructions on how to run the code.

## Data

A collection of argumentation frameworks, which our scripts use for the experiments, is included in the `AFs/` folder. We generated them using the Barabási-Albert algorithm implemented in the `AFBenchGen2` java tool (see the paper for more details on this). This tool is available online:

    https://sourceforge.net/projects/afbenchgen/

Inside this folder, each file is named as follows:

    BarabasiAlbert_n<args>_p<prob>_<id>

Where `<args>` is the number of arguments, `<prob>` the probability of each node to be in a cycle, and `<id>` a number to identify unique files. Each file is encoded in a format compatible with `ASPARTIX`. This is the tool we use in our code for the argumentation reasoning tasks. See the homepage of `ASPARTIX` for more information:

    https://www.dbai.tuwien.ac.at/research/argumentation/aspartix/

## Requirements and Code Structure

The code is written for Python3, and tested with version 3.7.3. Besides the standard packages, the following are required:

* `clingo`
* `tqdm`
* `numpy`
* `multiprocessing`
* `matplotlib`
* `scipy`

The python file `absaf.py` contains a class implementing our model, the Approval-Based Social Argumentation Framework. The file `asp.py` includes the `ASPARTIX`-based ASP encodings used to perform some argumentation reasoning tasks. The remaining Python files are described in the following sections. The `*.pkl` files contain the results of the experiments we describe in the paper, and are also described below.

## Running the Main Experiments

To run the experiments:

    python batch_experiments.py <file>.pkl

This will save the results in `<file>.pkl`. To plot the results:

    python plot_experiments.py <file>.pkl

Note that `plot_experiments.py` visualizes (but does not save) various plots, and to see the next plot, you need to close the current window. In order, it shows:

* Average representation score compared to dispersion value, with normal representation;
* Minimal representation score compared to dispersion value, with normal representation;
* "Recover score" compared to dispersion value, with normal representation;
    * Given outcome S this score is computed as |{E in S : E is a ground truth}| / |S|
* Percentage of 1-represented voters compared to dispersion value, with normal representation;
* Percentage of 0.5-represented voters compared to dispersion value, with normal representation;

* The same four plots as above, but with DefCore representation;

* Given a function f that picks an outcome maximizing score f-SCORE, we plot:
    * the percentage of the f-SCORE of the outcome chosen by f, against the f-SCORE of the set of all preferred extensions (against the dispersion value, and with normal representation);
    * the percentage of the f-SCORE of the outcome chosen by greedy-f, against the f-SCORE of the outcome chosen by f (against the dispersion value, and with normal representation);

* The same two plots as above, but with DefCore representation.

We include three pre-made results file: `experiments_k2.pkl`, `experiments_k3.pkl` and `experiments_k5.pkl` for k=2, 3 and 5 (respectively). These include the results shown in the paper.

## Running the Varying-k Experiments

To run the experiments:

    python varying_k_experiment.py <file>.pkl

This will save the results in `<file>.pkl`. To plot the results:

    python plot_varying_k.py <file>.pkl

Note that `plot_varying_k.py` visualizes (but does not save) various plots, and to see the next plot, you need to close the current window. It shows the results for the experiment for each function considered.

We include a pre-made results file, `varying_k.pkl`. This includes the results shown in the paper.

## Running the Performance Experiments

To run the experiments:

    python performance_experiment.py <file>.pkl

The results are printed on screen, and saved in `<file>.pkl`. To print them again:

    python print_performance.py.py <file>.pkl

We include three pre-made results files, `performance_util.pkl`, `performance_egal.pkl`, and `performance_maxCov.pkl`, for the Utilitarian, Egalitarian and MaxCover functions. These include the results shown in the paper.